==> ignorance-1.3.0.1.tar.bz2: ignorance-1.3.0.1/ignorance_rule.h <==
#ifndef IGNORANCE_RULE_H
#define IGNORANCE_RULE_H

#include <stdlib.h>
#include <sys/types.h>
#include <regex.h>
#include <glib.h>
#include <glib/gprintf.h>

#include "debug.h"


#define IGNORANCE_RULE_INVALID 0
#define IGNORANCE_RULE_MINVALID INT_MAX

#define IGNORANCE_RULE_SIMPLETEXT 1
#define IGNORANCE_RULE_SIMPLETEXT_NUMTOKENS 6

#define IGNORANCE_RULE_REGEX 2
#define IGNORANCE_RULE_REGEX_NUMTOKENS 6




//	describes an ignorance rule
//
//	name - user's name for the rule
//	type - one of the ruletypes defined within this struct
//
//	value - the actual value of the rule
//	could be a string/regex, integer, other
//	depending on the rule type
//
//	score - an arbitrary (user-assigned) number
//	that determines the severity of the rule
typedef struct ignorance_rule {
	GString	*name;
	gint	type;
	gchar	*value;
	gint	score;
	gint	flags;
	gboolean	enabled;
} ignorance_rule;

ignorance_rule*	ignorance_rule_new();

//name and value will be freed by ignorance_rule_free
ignorance_rule*	ignorance_rule_newp(const GString *name, gint type, const gchar *value, gint score, gint flags, gboolean enabled);
void			ignorance_rule_free(ignorance_rule *ir);	//DEEP destruction!
void			ignorance_rule_free_g(gpointer ir,gpointer user_data);	//DEEP destruction!

gboolean	ignorance_rule_has_type(gint type);

//	Determines whether a string violates a rule
//
//	rule is the rule
//	text is the possibly offending string
//	returns 0/1 boolean
gint	ignorance_rule_rulecheck(ignorance_rule *rule, const GString *text, gint flags);

//ignorance_rule*	ignorance_rule_parse(const gchar *ruletext);

//simple text
gint	simple_text_rulecheck(ignorance_rule *rule, const GString *text);

// Parses the textual representation of a simple text rule into an ignorance_rule
//ignorance_rule*	simple_text_ruleparse(const gchar *ruletext);

//regex
gint	regex_rulecheck(ignorance_rule *rule, const GString *text);

// Parses the textual representation of a regex rule into an ignorance_rule
//ignorance_rule*	regex_ruleparse(const gchar *ruletext);

// Parses the textual representation of a rule into an ignorance_rule
ignorance_rule*	ignorance_rule_read(const gchar *ruletext);

// Writes out an ignorance rule to a file
//
// rule is the rule to write
// f is the file which will be written
// success/failure returned
gboolean	ignorance_rule_write(ignorance_rule *rule,FILE *f);

#endif

==> ignorance-2.2.tar.bz2: ignorance-2.2/ignorance_rule.h <==
#ifndef IGNORANCE_RULE_H
#define IGNORANCE_RULE_H

#include <stdlib.h>
#include <sys/types.h>
#include <glib.h>
#include <glib/gprintf.h>

#include "debug.h"


#define IGNORANCE_RULE_INVALID 0
#define IGNORANCE_RULE_MINVALID INT_MAX

#define IGNORANCE_RULE_SIMPLETEXT 1
#define IGNORANCE_RULE_SIMPLETEXT_NUMTOKENS 6

#ifdef HAVE_REGEX_H
#include <regex.h>
#define IGNORANCE_RULE_REGEX 2
#define IGNORANCE_RULE_REGEX_NUMTOKENS 6
#endif

#define IGNORANCE_FLAG_FILTER	1
#define IGNORANCE_FLAG_IGNORE	2
#define IGNORANCE_FLAG_MESSAGE  4
#define IGNORANCE_FLAG_EXECUTE	8
#define IGNORANCE_FLAG_SOUND	16




//	describes an ignorance rule
//
//	name - user's name for the rule
//	type - one of the ruletypes defined within this struct
//
//	value - the actual value of the rule
//	could be a string/regex, integer, other
//	depending on the rule type
//
//	score - an arbitrary (user-assigned) number
//	that determines the severity of the rule
typedef struct ignorance_rule {
	GString	*name;
	gint	type;
	gchar	*value;
	gint	score;
	gint	flags;
	gboolean	enabled;
	gchar	*message,
		*command,
		*sound;
} ignorance_rule;

ignorance_rule*	ignorance_rule_new();

//name and value will be freed by ignorance_rule_free
ignorance_rule*	ignorance_rule_newp(const GString *name, gint type, const gchar *value, gint score, gint flags, gboolean enabled,const gchar *message,const gchar *sound, const gchar *command);
void			ignorance_rule_free(ignorance_rule *ir);	//DEEP destruction!
void			ignorance_rule_free_g(gpointer ir,gpointer user_data);	//DEEP destruction!

gboolean	ignorance_rule_has_type(gint type);

//	Determines whether a string violates a rule
//
//	rule is the rule
//	text is the possibly offending string
//	returns 0/1 boolean
gint	ignorance_rule_rulecheck(ignorance_rule *rule, const GString *text, gint flags);

//ignorance_rule*	ignorance_rule_parse(const gchar *ruletext);

//simple text
gint	simple_text_rulecheck(ignorance_rule *rule, const GString *text);

// Parses the textual representation of a simple text rule into an ignorance_rule
//ignorance_rule*	simple_text_ruleparse(const gchar *ruletext);

#ifdef HAVE_REGEX_H
//regex
gint	regex_rulecheck(ignorance_rule *rule, const GString *text);
#endif

// Parses the textual representation of a regex rule into an ignorance_rule
//ignorance_rule*	regex_ruleparse(const gchar *ruletext);

// Parses the textual representation of a rule into an ignorance_rule
ignorance_rule*	ignorance_rule_read(const gchar *ruletext);

// Writes out an ignorance rule to a file
//
// rule is the rule to write
// f is the file which will be written
// success/failure returned
gboolean	ignorance_rule_write(ignorance_rule *rule,FILE *f);

#endif
